diff options
| author | Markus Wick <markus@selfnet.de> | 2020-01-11 13:52:34 +0100 |
|---|---|---|
| committer | Markus Wick <markus@selfnet.de> | 2020-01-11 14:04:44 +0100 |
| commit | 2049ebc50eaa6f2d21bdda23a7297f21dbc25125 (patch) | |
| tree | 2c34aa7092c81ba93fe9a76e7a64967985142f68 /src/core/loader/nso.cpp | |
| parent | 36e23e4cda0ac8b8410f45f85d97b951cb851420 (diff) | |
core/kernel: Fix GetTotalPhysicalMemoryUsed.
module._memory was already moved over to a new shared_ptr.
So code_memory_size was not increased at all.
This lowers the heap space and so saves a bit of memory, usually between 50 to 100 MB.
This fixes a regression of b8ccd49d77feb52aa333cd30e5d7c28423c5455d
Diffstat (limited to 'src/core/loader/nso.cpp')
0 files changed, 0 insertions, 0 deletions
